LocalSource

Struct LocalSource 

pub struct LocalSource { /* private fields */ }

Implementations

Source

impl LocalSource

pub fn manifest_path(&self) -> &Path

pub fn target_dir(&self) -> &Path

pub fn root_crate(&self) -> Option<&CrateName<'static>>

pub fn can_rebuild(&self) -> bool

Source

impl LocalSource

pub fn load(path: &Path) -> Result<Self>

pub fn is_workspace_package(&self, crate_name: &str) -> bool

Check if a crate name is a workspace package

pub fn get_dependency_version<'a, 'b: 'a>( &'a self, crate_name: &'b str, ) -> Option<&'a Version>

Get the resolved version for a dependency Returns None if not a dependency or if it’s a path/workspace dep

pub fn project_root(&self) -> &Path

Get the project root

pub fn can_load(&self, crate_name: &str) -> bool

Check if this source can provide a given crate

pub fn load_workspace_crate( &self, crate_name: CrateName<'_>, ) -> Option<RustdocData>

Load a workspace crate (may rebuild if needed)

pub fn load_dep( &self, crate_name: CrateName<'_>, version: Option<&Version>, ) -> Option<RustdocData>

Load a dependency crate (may rebuild if needed)